@@ -17,9 +17,13 @@ class Mensaje(BaseModel):
 
     @classmethod
     def parse_xml(cls, mensaje):  # noqa: WPS210
-        decoded = mensaje.decode('latin1').replace('&amp;', '&amp;amp;')
-        encoded = decoded.encode('utf-8')
-        mensaje = etree.fromstring(encoded)  # noqa: S320
+        is_ensesion = mensaje.find(b'ENSESION')
+        if is_ensesion == -1:
+            decoded = mensaje.decode('utf-8')
+        else:
+            decoded = mensaje.decode('latin1').replace('&amp;', '&amp;amp;')
+
+        mensaje = etree.fromstring(bytes(decoded, encoding='utf-8'))  # noqa: S320
         body = mensaje.find(
             '{http://schemas.xmlsoap.org/soap/envelope/}Body',
         )
