@@ -10,19 +10,13 @@ class Respuesta(BaseModel):
     fecha_oper: int
     err_codigo: types.CodigoError
     err_descripcion: str
-    categoria: types.CategoriaRespuesta
+    categoria: types.CategoriaOrdenPago
 
     class Config:  # noqa: WPS306, WPS431
         use_enum_values = True
 
     def build_xml(self):
-        qname = etree.QName('http://www.w3.org/2001/XMLSchema-instance', 'type')
-        mensaje = etree.Element(
-            'mensaje',
-            {qname: 'mensaje'},
-            categoria=self.categoria,
-        )
-        respuesta = etree.SubElement(mensaje, 'respuesta')
+        respuesta = etree.Element('respuesta')
 
         for element, value in self.dict(exclude={'categoria'}).items():  # noqa: WPS110
             if element in self.__fields__:
@@ -30,17 +24,15 @@ class Respuesta(BaseModel):
                 subelement = etree.SubElement(respuesta, upper_camel_case_element)
                 subelement.text = str(value)
 
-        return mensaje
+        return respuesta
 
     @classmethod
-    def parse_xml(cls, mensaje_element):
-        respuesta = mensaje_element.find('respuesta')
-
+    def parse_xml(cls, respuesta_element, categoria: types.CategoriaOrdenPago):
         respuesta_data = {
-            'categoria': mensaje_element.attrib['categoria'],
+            'categoria': categoria,
         }
 
-        for sub_element in respuesta.getchildren():
+        for sub_element in respuesta_element.getchildren():
             tag = to_snake_case(sub_element.tag)
             respuesta_data[tag] = sub_element.text
 
